package com.vendor.platform.ui.internal;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.platform.api.IDeviceManager;
import com.vendor.platform.api.chips.Chips;
import com.vendor.platform.core.PlatformCoreActivator;
import com.vendor.platform.core.ToolDescriptor;
import com.vendor.platform.core.internal.DeviceManager;
import com.vendor.platform.ui.Messages;
import com.vendor.platform.ui.PlatformUIActivator;
import com.vendor.platform.ui.internal.PerspectiveUtil;
import com.vendor.platform.ui.internal.RegisterUtils;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.eclipse.core.runtime.IExtension;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.MultiStatus;
import org.eclipse.core.runtime.Platform;
import org.eclipse.core.runtime.Plugin;
import org.eclipse.core.runtime.Status;
import org.eclipse.help.internal.HelpPlugin;
import org.eclipse.osgi.service.resolver.BundleDescription;
import org.eclipse.osgi.service.resolver.DisabledInfo;
import org.eclipse.osgi.service.resolver.PlatformAdmin;
import org.eclipse.osgi.service.resolver.ResolverError;
import org.eclipse.osgi.service.resolver.State;
import org.eclipse.osgi.service.resolver.VersionConstraint;
import org.eclipse.ui.internal.registry.PerspectiveDescriptor;
import org.eclipse.ui.internal.registry.PerspectiveRegistry;
import org.osgi.framework.Bundle;
import org.osgi.framework.BundleContext;
import org.osgi.framework.BundleException;
import org.osgi.service.packageadmin.PackageAdmin;
import org.osgi.util.tracker.ServiceTracker;

public class BundleUtils {
  public static final String[][] TOOLS_AND_CLASSES_ARR = new String[][] { { "BurnTool", "FastplayBinTool", "LoaderBinTool", "RegBinTool", "VRCTool", "PanelBinTool" }, { "com.vendor.burn.perspectives.FastbootPerspective", "com.vendor.fastplay.perspectives.FastplayPerspective", "com.vendor.loader.perspectives.Perspective", "com.vendor.regbin.perspectives.RegbinPerspective", "com.vendor.vrc.perspectrives.Perspective", "com.vendor.panel.perspectives.PanelPerspective" } };
  
  public static final String PACK_NAME = "com.vendor";
  
  public static final Map<String, String> PERS_BUNDLE_ID_MAP = new HashMap<>();
  
  private static com.vendor.platform.ui.internal.BundleUtils instance;
  
  private ServiceTracker packageAdminTracker;
  
  private ServiceTracker platformAdminTracker;
  
  public static String findBundleIDByPersID(PerspectiveRegistry perspectiveReg, String id) {
    PerspectiveDescriptor perspective = (PerspectiveDescriptor)perspectiveReg.findPerspectiveWithId(id);
    String bundleId = null;
    if (perspective != null) {
      Bundle bundle = Platform.getBundle(perspective.getPluginId());
      if (bundle != null)
        bundleId = String.valueOf(bundle.getBundleId()); 
    } 
    return bundleId;
  }
  
  public static synchronized void insertMapping(String persID, String bundleID) {
    if (bundleID != null && bundleID.length() > 0)
      PERS_BUNDLE_ID_MAP.put(persID, bundleID); 
  }
  
  private BundleUtils(BundleContext context) {
    this
      .packageAdminTracker = new ServiceTracker(context, PackageAdmin.class.getName(), null);
    this.packageAdminTracker.open();
    this
      .platformAdminTracker = new ServiceTracker(context, PlatformAdmin.class.getName(), null);
    this.platformAdminTracker.open();
  }
  
  public static synchronized com.vendor.platform.ui.internal.BundleUtils getInstance() {
    if (instance == null)
      instance = new com.vendor.platform.ui.internal.BundleUtils(PlatformUIActivator.getDefault().getContext()); 
    return instance;
  }
  
  public State getBundlesState() {
    PackageAdmin packageAdmin = (PackageAdmin)getPlatformAdmin();
    if (packageAdmin == null)
      return null; 
    return getPlatformAdmin().getState(false);
  }
  
  public PackageAdmin getPackageAdmin() {
    if (this.packageAdminTracker == null)
      return null; 
    return (PackageAdmin)this.packageAdminTracker.getService();
  }
  
  public PlatformAdmin getPlatformAdmin() {
    if (this.platformAdminTracker == null)
      return null; 
    return (PlatformAdmin)this.platformAdminTracker.getService();
  }
  
  public static void startBundle(long id) throws BundleException {
    PlatformCoreActivator.getBundleContext().getBundle(id)
      .start();
  }
  
  public static void stopBundle(long id) throws BundleException {
    PlatformCoreActivator.getBundleContext().getBundle(id)
      .stop();
  }
  
  public static void startBundle(String name) throws BundleException {
    if (getBundleId(name) != null)
      startBundle(getBundleId(name).longValue()); 
  }
  
  public static void stopBundle(String name) throws BundleException {
    if (getBundleId(name) != null)
      stopBundle(getBundleId(name).longValue()); 
  }
  
  public static Long getBundleId(String name) {
    BundleDescription descr = PlatformCoreActivator.getDefault().getPlatformAdmin().getState(false).getBundle(name, null);
    return (descr == null) ? null : Long.valueOf(descr.getBundleId());
  }
  
  public static boolean isToolEnabled(ToolDescriptor tool) {
    List<ToolDescriptor.PluginDetail> list = tool.getPlugins();
    if (list.size() == 0)
      return true; 
    return isBundleEnabled(((ToolDescriptor.PluginDetail)list.get(0)).getPluginId());
  }
  
  public static boolean isToolRegistered(ToolDescriptor tool) {
    Date d = RegisterUtils.getRegisterDate(tool.getProperties());
    if (d != null)
      return true; 
    return false;
  }
  
  public static boolean isBundleEnabled(String name) {
    State state = PlatformCoreActivator.getDefault().getPlatformAdmin().getState(false);
    BundleDescription descr = state.getBundle(name, null);
    if (descr != null)
      return isBundleEnabled(descr.getBundle()); 
    return false;
  }
  
  public static boolean isBundleEnabled(Bundle bundle) {
    PlatformAdmin plaformAdmin = PlatformCoreActivator.getDefault().getPlatformAdmin();
    State state = plaformAdmin.getState(false);
    if (state != null && bundle != null) {
      BundleDescription description = state.getBundle(bundle
          .getBundleId());
      return ((state.getDisabledInfos(description)).length == 0);
    } 
    return false;
  }
  
  public static void setBundleEnabled(String name, boolean enabled) {
    Long bundleId = getBundleId(name);
    if (bundleId != null)
      setBundleEnabled(bundleId.longValue(), enabled); 
  }
  
  public static void setBundleEnabled(long id, boolean enabled) {
    State state = PlatformCoreActivator.getDefault().getState();
    BundleDescription desc = state.getBundle(id);
    if (desc == null)
      return; 
    if (enabled) {
      DisabledInfo[] infos = state.getDisabledInfos(desc);
      if (infos != null)
        for (int i = 0; i < infos.length; i++) {
          PlatformAdmin platformAdmin = PlatformCoreActivator.getDefault().getPlatformAdmin();
          platformAdmin.removeDisabledInfo(infos[i]);
        }  
    } else {
      DisabledInfo info = new DisabledInfo("org.eclipse.pde.ui", "Disabled via PDE", desc);
      PlatformAdmin platformAdmin = PlatformCoreActivator.getDefault().getPlatformAdmin();
      platformAdmin.addDisabledInfo(info);
    } 
    Bundle b = PlatformCoreActivator.getBundleContext().getBundle(id);
    PackageAdmin packageAdmin = PlatformCoreActivator.getDefault().getPackageAdmin();
    if (packageAdmin != null)
      packageAdmin.refreshPackages(new Bundle[] { b }); 
    try {
      HelpPlugin.getTocManager().clearCache();
    } catch (Exception exception) {}
  }
  
  public static synchronized void closeToolPerspective(ToolDescriptor tool) {
    Map<String, IExtension> reg = PerspectiveUtil.loadPerspectiveRegistry();
    List<String> ids = PerspectiveUtil.finPerspectiveDeclareIds(tool, reg);
    if (ids.size() == 0)
      return; 
    String id = ids.get(0);
    PerspectiveUtil.closePerpective(id);
  }
  
  public static synchronized void closeToolPerspective(Map<String, IExtension> perspectiveRegistry, Plugin plugin) {
    IExtension ext = perspectiveRegistry.get(plugin.getBundle()
        .getHeaders().get("Bundle-Name"));
    if (ext == null)
      return; 
    List<String> ids = PerspectiveUtil.finPerspectiveDeclareIds(ext);
    if (ids.isEmpty())
      return; 
    String id = ids.get(0);
    PerspectiveUtil.closePerpective(id);
  }
  
  public MultiStatus diagnoseBundleStatus(long id) {
    PlatformAdmin plaformAdmin = PlatformCoreActivator.getDefault().getPlatformAdmin();
    State state = plaformAdmin.getState(false);
    BundleDescription desc = state.getBundle(id);
    PlatformAdmin platformAdmin = PlatformCoreActivator.getDefault().getPlatformAdmin();
    VersionConstraint[] unsatisfied = platformAdmin.getStateHelper().getUnsatisfiedConstraints(desc);
    ResolverError[] resolverErrors = platformAdmin.getState(false).getResolverErrors(desc);
    MultiStatus problems = new MultiStatus("com.vendor.platform.core", 1, Messages.BundleUtils_0, null);
    int i;
    for (i = 0; i < resolverErrors.length; i++) {
      if ((resolverErrors[i].getType() & 0x8007) == 0) {
        Status status = new Status(2, "com.vendor.platform.core", resolverErrors[i].toString());
        problems.add((IStatus)status);
      } 
    } 
    for (i = 0; i < unsatisfied.length; i++) {
      Status status = new Status(2, "com.vendor.platform.core", MessageHelper.getResolutionFailureMessage(unsatisfied[i]));
      problems.add((IStatus)status);
    } 
    return problems;
  }
  
  public Bundle getBundle(String symbolicName) {
    PackageAdmin packageAdmin = getPackageAdmin();
    if (packageAdmin == null)
      return null; 
    Bundle[] bundles = packageAdmin.getBundles(symbolicName, null);
    if (bundles == null)
      return null; 
    for (int i = 0; i < bundles.length; i++) {
      if ((bundles[i].getState() & 0x1) == 0)
        return bundles[i]; 
    } 
    return null;
  }
  
  public static boolean suitableForChip(ToolDescriptor tool, String chip) {
    Chips chips = DeviceManager.getCurrentChips();
    ArrayList<String> suiltableToolIDs = chips.getSuitableToolIDs(chip);
    if (suiltableToolIDs != null && suiltableToolIDs.size() > 0 && 
      suiltableToolIDs.contains(tool.getProperties().get("build.id")))
      return true; 
    return false;
  }
  
  public static boolean isExistentTool(String packId) {
    Chips chips = DeviceManager.getCurrentChips();
    IDeviceManager dm = DeviceManager.getInstance();
    ArrayList<String> suiltableToolIDs = chips.getSuitableToolIDs(dm.getCurrentDevice());
    if ("Flasher".equals(suiltableToolIDs.get(0)))
      suiltableToolIDs.set(0, "BurnTool"); 
    String[] toolsMap = TOOLS_AND_CLASSES_ARR[0];
    String[] classMap = TOOLS_AND_CLASSES_ARR[1];
    for (int i = 0; i < suiltableToolIDs.size(); i++) {
      for (int j = 0; j < toolsMap.length; j++) {
        if (((String)suiltableToolIDs.get(i)).equals(toolsMap[j]) && classMap[j].equals(packId))
          return true; 
      } 
    } 
    return false;
  }
  
  public static boolean isSuitForTool(PerspectiveDescriptor perspective) {
    if (isExistentTool(perspective.getId()))
      return true; 
    return false;
  }
}
